searchData={"items":[{"type":"module","title":"FileSystem","doc":"A `GenServer` process to watch file system changes.\n\nThe process receives data from Port, parse event, and send it to the worker\nprocess.","ref":"FileSystem.html"},{"type":"function","title":"FileSystem.start_link/1","doc":"Starts a `GenServer` process and linked to the current process.","ref":"FileSystem.html#start_link/1"},{"type":"function","title":"Options - FileSystem.start_link/1","doc":"* `:dirs` ([string], required), the list of directory to monitor.\n\n  * `:backend` (atom, optional), default backends: `:fs_mac`. Available\n    backends: `:fs_mac`, `:fs_inotify`, and `:fs_windows`.\n\n  * `:name` (atom, optional), the `name` of the worker process to subscribe\n    to the file system listener. Alternative to using `pid` of the worker\n    process.\n\n  * Additional backend implementation options. See backend module documents\n    for more details.","ref":"FileSystem.html#start_link/1-options"},{"type":"function","title":"Examples - FileSystem.start_link/1","doc":"Start monitoring `/tmp/fs` directory using the default `:fs_mac` backend of\nthe current process:\n\n    iex> {:ok, pid} = FileSystem.start_link(dirs: [\"/tmp/fs\"])\n    iex> FileSystem.subscribe(pid)\n\nGet instant (`latench: 0`) notifications on file changes:\n\n    iex> FileSystem.start_link(dirs: [\"/path/to/some/files\"], latency: 0)\n\nMonitor a directory by a process name:\n\n    iex> FileSystem.start_link(backend: :fs_mac, dirs: [\"/tmp/fs\"], name: :worker)\n    iex> FileSystem.subscribe(:worker)","ref":"FileSystem.html#start_link/1-examples"},{"type":"function","title":"FileSystem.subscribe/1","doc":"Register the current process as a subscriber of a `file_system` worker.\n\nThe `pid` you subscribed from will now receive messages like:\n\n    {:file_event, worker_pid, {file_path, events}}\n    {:file_event, worker_pid, :stop}","ref":"FileSystem.html#subscribe/1"},{"type":"behaviour","title":"FileSystem.Backend","doc":"A behaviour module for implementing different file system backend.","ref":"FileSystem.Backend.html"},{"type":"function","title":"FileSystem.Backend.backend/1","doc":"Get and validate backend module.\n\nReturns `{:ok, backend_module}` upon success and `{:error, reason}` upon\nfailure.\n\nWhen `nil` is given, will return default backend by OS.\n\nWhen a custom module is given, make sure `start_link/1`, `bootstrap/0` and\n`supported_system/0` are defnied.","ref":"FileSystem.Backend.html#backend/1"},{"type":"callback","title":"FileSystem.Backend.bootstrap/0","doc":"","ref":"FileSystem.Backend.html#c:bootstrap/0"},{"type":"callback","title":"FileSystem.Backend.known_events/0","doc":"","ref":"FileSystem.Backend.html#c:known_events/0"},{"type":"callback","title":"FileSystem.Backend.supported_systems/0","doc":"","ref":"FileSystem.Backend.html#c:supported_systems/0"},{"type":"module","title":"FileSystem.Backends.FSInotify","doc":"File system backend for GNU/Linux, FreeBSD, DragonFly and OpenBSD.\n\nThis file is a fork from https://github.com/synrc/fs.","ref":"FileSystem.Backends.FSInotify.html"},{"type":"module","title":"Backend Options - FileSystem.Backends.FSInotify","doc":"* `:recursive` (bool, default: true), monitor directories and their contents recursively.","ref":"FileSystem.Backends.FSInotify.html#module-backend-options"},{"type":"module","title":"Executable File Path - FileSystem.Backends.FSInotify","doc":"Useful when running `:file_system` with escript.\n\nThe default listener executable file is found through finding `inotifywait` from\n`$PATH`.\n\nTwo ways to customize the executable file path:\n\n  * Module config with `config.exs`:\n\n    ```elixir\n    config :file_system, :fs_inotify,\n      executable_file: \"YOUR_EXECUTABLE_FILE_PATH\"`\n    ```\n\n  * System environment variable:\n\n    ```\n    export FILESYSTEM_FSINOTIFY_EXECUTABLE_FILE=\"YOUR_EXECUTABLE_FILE_PATH\"`\n    ```","ref":"FileSystem.Backends.FSInotify.html#module-executable-file-path"},{"type":"function","title":"FileSystem.Backends.FSInotify.bootstrap/0","doc":"","ref":"FileSystem.Backends.FSInotify.html#bootstrap/0"},{"type":"function","title":"FileSystem.Backends.FSInotify.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"FileSystem.Backends.FSInotify.html#child_spec/1"},{"type":"function","title":"FileSystem.Backends.FSInotify.init/1","doc":"","ref":"FileSystem.Backends.FSInotify.html#init/1"},{"type":"function","title":"FileSystem.Backends.FSInotify.known_events/0","doc":"","ref":"FileSystem.Backends.FSInotify.html#known_events/0"},{"type":"function","title":"FileSystem.Backends.FSInotify.parse_line/1","doc":"","ref":"FileSystem.Backends.FSInotify.html#parse_line/1"},{"type":"function","title":"FileSystem.Backends.FSInotify.parse_options/1","doc":"","ref":"FileSystem.Backends.FSInotify.html#parse_options/1"},{"type":"function","title":"FileSystem.Backends.FSInotify.start_link/1","doc":"","ref":"FileSystem.Backends.FSInotify.html#start_link/1"},{"type":"function","title":"FileSystem.Backends.FSInotify.supported_systems/0","doc":"","ref":"FileSystem.Backends.FSInotify.html#supported_systems/0"},{"type":"module","title":"FileSystem.Backends.FSMac","doc":"File system backend for MacOS.\n\nThe built-in executable file will be compile upon first use.\n\nThis file is a fork from https://github.com/synrc/fs.","ref":"FileSystem.Backends.FSMac.html"},{"type":"module","title":"Backend Options - FileSystem.Backends.FSMac","doc":"* `:latency` (float, default: 0.5), latency period.\n\n  * `:no_defer` (bool, default: false), enable no-defer latency modifier.\n    Works with latency parameter.\n\n    See `FSEvent` API documents\n    https://developer.apple.com/documentation/coreservices/kfseventstreamcreateflagnodefer.\n\n  * `:watch_root` (bool, default: false), watch for when the root path has changed.\n    Set the flag `true` to monitor events when watching `/tmp/fs/dir` and run\n    `mv /tmp/fs /tmp/fx`.\n\n    See `FSEvent` API documents\n    https://developer.apple.com/documentation/coreservices/kfseventstreamcreateflagwatchroot.\n\n  * recursive is enabled by default and it can'b be disabled for now.","ref":"FileSystem.Backends.FSMac.html#module-backend-options"},{"type":"module","title":"Executable File Path - FileSystem.Backends.FSMac","doc":"Useful when running `:file_system` with escript.\n\nThe default listener executable file is `priv/mac_listener` within the folder of\n`:file_system` application.\n\nTwo ways to customize the executable file path:\n\n  * Module config with `config.exs`:\n\n    ```elixir\n    config :file_system, :fs_mac,\n      executable_file: \"YOUR_EXECUTABLE_FILE_PATH\"`\n    ```\n\n  * System environment variable:\n\n    ```\n    export FILESYSTEM_FSMAC_EXECUTABLE_FILE=\"YOUR_EXECUTABLE_FILE_PATH\"`\n    ```","ref":"FileSystem.Backends.FSMac.html#module-executable-file-path"},{"type":"function","title":"FileSystem.Backends.FSMac.bootstrap/0","doc":"","ref":"FileSystem.Backends.FSMac.html#bootstrap/0"},{"type":"function","title":"FileSystem.Backends.FSMac.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"FileSystem.Backends.FSMac.html#child_spec/1"},{"type":"function","title":"FileSystem.Backends.FSMac.init/1","doc":"","ref":"FileSystem.Backends.FSMac.html#init/1"},{"type":"function","title":"FileSystem.Backends.FSMac.known_events/0","doc":"","ref":"FileSystem.Backends.FSMac.html#known_events/0"},{"type":"function","title":"FileSystem.Backends.FSMac.parse_line/1","doc":"","ref":"FileSystem.Backends.FSMac.html#parse_line/1"},{"type":"function","title":"FileSystem.Backends.FSMac.parse_options/1","doc":"","ref":"FileSystem.Backends.FSMac.html#parse_options/1"},{"type":"function","title":"FileSystem.Backends.FSMac.start_link/1","doc":"","ref":"FileSystem.Backends.FSMac.html#start_link/1"},{"type":"function","title":"FileSystem.Backends.FSMac.supported_systems/0","doc":"","ref":"FileSystem.Backends.FSMac.html#supported_systems/0"},{"type":"module","title":"FileSystem.Backends.FSPoll","doc":"File system backend for any OS.","ref":"FileSystem.Backends.FSPoll.html"},{"type":"module","title":"Backend Options - FileSystem.Backends.FSPoll","doc":"* `:interval` (integer, default: 1000), polling interval","ref":"FileSystem.Backends.FSPoll.html#module-backend-options"},{"type":"module","title":"Using FSPoll Backend - FileSystem.Backends.FSPoll","doc":"Unlike other backends, polling backend is never automatically chosen in any\nOS environment, despite being usable on all platforms.\n\nTo use polling backend, one has to explicitly specify in the backend option.","ref":"FileSystem.Backends.FSPoll.html#module-using-fspoll-backend"},{"type":"function","title":"FileSystem.Backends.FSPoll.bootstrap/0","doc":"","ref":"FileSystem.Backends.FSPoll.html#bootstrap/0"},{"type":"function","title":"FileSystem.Backends.FSPoll.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"FileSystem.Backends.FSPoll.html#child_spec/1"},{"type":"function","title":"FileSystem.Backends.FSPoll.init/1","doc":"","ref":"FileSystem.Backends.FSPoll.html#init/1"},{"type":"function","title":"FileSystem.Backends.FSPoll.known_events/0","doc":"","ref":"FileSystem.Backends.FSPoll.html#known_events/0"},{"type":"function","title":"FileSystem.Backends.FSPoll.start_link/1","doc":"","ref":"FileSystem.Backends.FSPoll.html#start_link/1"},{"type":"function","title":"FileSystem.Backends.FSPoll.supported_systems/0","doc":"","ref":"FileSystem.Backends.FSPoll.html#supported_systems/0"},{"type":"module","title":"FileSystem.Backends.FSWindows","doc":"File system backend for Windows.\n\nNeed binary executable file packaged in to use this backend.\n\nThis file is a fork from https://github.com/synrc/fs.","ref":"FileSystem.Backends.FSWindows.html"},{"type":"module","title":"Backend Options - FileSystem.Backends.FSWindows","doc":"* `:recursive` (bool, default: true), monitor directories and their contents recursively","ref":"FileSystem.Backends.FSWindows.html#module-backend-options"},{"type":"module","title":"Executable File Path - FileSystem.Backends.FSWindows","doc":"Useful when running `:file_system` with escript.\n\nThe default listener executable file is `priv/inotifywait.exe` within the\nfolder of `:file_system` application.\n\nTwo ways to customize the executable file path:\n\n  * Module config with `config.exs`:\n\n    ```elixir\n    config :file_system, :fs_windows,\n      executable_file: \"YOUR_EXECUTABLE_FILE_PATH\"`\n    ```\n\n  * System environment variable:\n\n    ```\n    export FILESYSTEM_FSWINDOWS_EXECUTABLE_FILE=\"YOUR_EXECUTABLE_FILE_PATH\"`\n    ```","ref":"FileSystem.Backends.FSWindows.html#module-executable-file-path"},{"type":"function","title":"FileSystem.Backends.FSWindows.bootstrap/0","doc":"","ref":"FileSystem.Backends.FSWindows.html#bootstrap/0"},{"type":"function","title":"FileSystem.Backends.FSWindows.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"FileSystem.Backends.FSWindows.html#child_spec/1"},{"type":"function","title":"FileSystem.Backends.FSWindows.init/1","doc":"","ref":"FileSystem.Backends.FSWindows.html#init/1"},{"type":"function","title":"FileSystem.Backends.FSWindows.known_events/0","doc":"","ref":"FileSystem.Backends.FSWindows.html#known_events/0"},{"type":"function","title":"FileSystem.Backends.FSWindows.parse_line/1","doc":"","ref":"FileSystem.Backends.FSWindows.html#parse_line/1"},{"type":"function","title":"FileSystem.Backends.FSWindows.parse_options/1","doc":"","ref":"FileSystem.Backends.FSWindows.html#parse_options/1"},{"type":"function","title":"FileSystem.Backends.FSWindows.start_link/1","doc":"","ref":"FileSystem.Backends.FSWindows.html#start_link/1"},{"type":"function","title":"FileSystem.Backends.FSWindows.supported_systems/0","doc":"","ref":"FileSystem.Backends.FSWindows.html#supported_systems/0"},{"type":"module","title":"FileSystem.Worker","doc":"FileSystem Worker Process with the backend GenServer, receive events from Port Process\nand forward it to subscribers.","ref":"FileSystem.Worker.html"},{"type":"function","title":"FileSystem.Worker.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"FileSystem.Worker.html#child_spec/1"},{"type":"extras","title":"FileSystem","doc":"# FileSystem\n\n[![Module Version](https://img.shields.io/hexpm/v/file_system.svg)](https://hex.pm/packages/file_system)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/file_system/)\n[![Total Download](https://img.shields.io/hexpm/dt/file_system.svg)](https://hex.pm/packages/file_system)\n[![License](https://img.shields.io/hexpm/l/file_system.svg)](https://github.com/falood/file_system/blob/master/LICENSE)\n[![Last Updated](https://img.shields.io/github/last-commit/falood/file_system.svg)](https://github.com/falood/file_system/commits/master)\n[![CI Linux](https://github.com/falood/file_system/actions/workflows/ci-linux.yml/badge.svg)](https://github.com/falood/file_system/actions)\n[![CI MacOS](https://github.com/falood/file_system/actions/workflows/ci-macos.yml/badge.svg)](https://github.com/falood/file_system/actions)\n[![CI Windows](https://github.com/falood/file_system/actions/workflows/ci-windows.yml/badge.svg)](https://github.com/falood/file_system/actions)\n\nAn Elixir file change watcher wrapper based on\n[FS](https://github.com/synrc/fs), the native file system listener.","ref":"readme.html"},{"type":"extras","title":"System Support - FileSystem","doc":"- MacOS - [fsevent](https://github.com/thibaudgg/rb-fsevent)\n- GNU/Linux, FreeBSD, DragonFly and OpenBSD - [inotify](https://github.com/rvoicilas/inotify-tools/wiki)\n- Windows - [inotify-win](https://github.com/thekid/inotify-win)\n\nOn MacOS 10.14, to compile `mac_listener`, run:\n\n```console\nopen /Library/Developer/CommandLineTools/Packages/macOS_SDK_headers_for_macOS_10.14.pkg\n```\n\nOn newer versions this file doesn't exist. But it still should work just fine as long as you have xcode installed.","ref":"readme.html#system-support"},{"type":"extras","title":"Usage - FileSystem","doc":"Add `file_system` to the `deps` of your mix.exs\n\n``` elixir\ndefmodule MyApp.Mixfile do\n  use Mix.Project\n\n  def project do\n  ...\n  end\n\n  defp deps do\n    [\n      {:file_system, \"~> 1.0\", only: :test},\n    ]\n  end\n  ...\nend\n```","ref":"readme.html#usage"},{"type":"extras","title":"Subscription API - FileSystem","doc":"You can spawn a worker and subscribe to events from it:\n\n```elixir\n{:ok, pid} = FileSystem.start_link(dirs: [\"/path/to/some/files\"])\nFileSystem.subscribe(pid)\n```\n\nor\n\n```elixir\n{:ok, pid} = FileSystem.start_link(dirs: [\"/path/to/some/files\"], name: :my_monitor_name)\nFileSystem.subscribe(:my_monitor_name)\n```\n\nThe `pid` you subscribed from will now receive messages like:\n\n```\n{:file_event, worker_pid, {file_path, events}}\n```\nand\n\n```\n{:file_event, worker_pid, :stop}\n```","ref":"readme.html#subscription-api"},{"type":"extras","title":"Example Using GenServer - FileSystem","doc":"```elixir\ndefmodule Watcher do\n  use GenServer\n\n  def start_link(args) do\n    GenServer.start_link(__MODULE__, args)\n  end\n\n  def init(args) do\n    {:ok, watcher_pid} = FileSystem.start_link(args)\n    FileSystem.subscribe(watcher_pid)\n    {:ok, %{watcher_pid: watcher_pid}}\n  end\n\n  def handle_info({:file_event, watcher_pid, {path, events}}, %{watcher_pid: watcher_pid} = state) do\n    # Your own logic for path and events\n    {:noreply, state}\n  end\n\n  def handle_info({:file_event, watcher_pid, :stop}, %{watcher_pid: watcher_pid} = state) do\n    # Your own logic when monitor stop\n    {:noreply, state}\n  end\nend\n```","ref":"readme.html#example-using-genserver"},{"type":"extras","title":"Backend Options - FileSystem","doc":"For each platform, you can pass extra options to the underlying listener\nprocess.\n\nEach backend supports different extra options, check backend module\ndocumentation for more details.\n\nHere is an example to get instant notifications on file changes for MacOS:\n\n```elixir\nFileSystem.start_link(dirs: [\"/path/to/some/files\"], latency: 0, watch_root: true)\n```","ref":"readme.html#backend-options"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}